.. currentmodule:: pycvcam

Optimize parameters of transformations
=============================================

.. autosummary::
   :toctree: ../_autosummary/

   optimize_parameters_gn
   optimize_parameters_trf
   optimize_camera_gn
   optimize_camera_trf
   optimize_chains_gn
   optimize_chains_trf
